@@ -26,6 +26,7 @@
 		h = as.double(h)
 	}
 	data = as.double(data)
+	mexdata = coredata(mexdata)
 	# flatten exogenous matrix
 	if(model[6]>0){
 		xmxreg = matrix( pars[idx[6,1]:idx[6,2]], ncol = model[6] )
@@ -33,10 +34,10 @@
 			imx =  xmxreg %*%t( matrix( mexdata, ncol = model[6] ) )
 		} else{
 			if(model[20] == model[6]){
-				imx = xmxreg %*%t( matrix( mexdata * h , ncol = model[6] ) )				
+				imx = xmxreg %*%t( matrix( mexdata * h , ncol = model[6] ) )
 			} else{
 				imx = xmxreg[,1:(model[6]-model[20]),drop=FALSE] %*%t( matrix( mexdata[,1:(model[6]-model[20]),drop=FALSE], ncol = model[6]-model[20] ) )
-				imx = imx + xmxreg[,(model[6]-model[20]+1):model[6],drop=FALSE] %*%t( matrix( mexdata[,(model[6]-model[20]+1):model[6],drop=FALSE]*h, ncol = model[20] ) )					
+				imx = imx + xmxreg[,(model[6]-model[20]+1):model[6],drop=FALSE] %*%t( matrix( mexdata[,(model[6]-model[20]+1):model[6],drop=FALSE]*h, ncol = model[20] ) )
 			}
 		}
 		imx = as.double(imx)
@@ -53,9 +54,9 @@
 	condm = double(length = T)
 	ans = list()
 	if(model[2]>0 | model[3]>0){
-		ans = try(.C("arfimaxfilterC", model = as.integer(model), pars = as.double(pars), 
-						idx = as.integer(idx[,1]-1), x = data, res = res, mexdata = mexdata, 
-						zrf = zrf, constm = constm, condm = condm, h = h, m = m, T = T,  
+		ans = try(.C("arfimaxfilterC", model = as.integer(model), pars = as.double(pars),
+						idx = as.integer(idx[,1]-1), x = data, res = res, mexdata = mexdata,
+						zrf = zrf, constm = constm, condm = condm, h = h, m = m, T = T,
 						PACKAGE = "rugarch"), silent = TRUE)
 		if(inherits(ans, "try-error") | any(is.nan(ans$res)) | any(is.na(ans$res)) | any(!is.finite(ans$res)) ){
 			res = data - pars[idx[1,1]]
@@ -96,7 +97,7 @@
 {
 	n = length(as.vector(x))
 	p = c(-darfima, rep(0,n-1))
-	
+
 	res = .C("fracdiff",n = as.integer(n), d = as.double(darfima), p = as.double(p),
 			x = as.double(x), ydiff = as.double(x), PACKAGE = "rugarch")
 	return(res$ydiff)
@@ -108,9 +109,9 @@
 	T = as.integer(N[2])
 	sigma = as.double(sigma)
 	zrf = as.double(zrf)
-	data = as.double(data)	
-	# flatten exogenous matrix	
-	if(model[6]>0) mexdata = as.double(as.vector(mexdata)) else mexdata = as.double(0)	
+	data = as.double(data)
+	# flatten exogenous matrix
+	if(model[6]>0) mexdata = as.double(as.vector(mexdata)) else mexdata = as.double(0)
 	z = double(T)
 	h = double(T)
 	res = as.double(res)
@@ -118,11 +119,11 @@
 	condm = double(T)
 	llh = double(1)
 	LHT = double(T)
-	
-	ans = try(.C("arfimafitC", model = as.integer(model), pars = as.double(pars), 
-					idx = as.integer(idx), sigma = sigma, x = data, res = res, 
-					mexdata = mexdata, zrf = zrf, constm = constm, condm = condm, 
-					m = m, T = T, h = h, z = z, llh = llh, LHT = LHT, 
+
+	ans = try(.C("arfimafitC", model = as.integer(model), pars = as.double(pars),
+					idx = as.integer(idx), x = data, res = res,
+					mexdata = mexdata, zrf = zrf, constm = constm, condm = condm,
+					m = m, T = T, z = z, llh = llh, LHT = LHT,
 					PACKAGE = "rugarch"), silent = TRUE)
 	if(inherits(ans, "try-error")){
 		return(0)
@@ -134,9 +135,9 @@
 
 .armaxsim = function(model, ipars, idx, constm, x, res, T, m)
 {
-	ans = try(.C("armaxsim", model = as.integer(model), pars = as.double(ipars[,1]), 
-					idx = as.integer(idx[,1]-1), x = as.double(x), res = as.double(res), 
-					constm = as.double(constm), m = as.integer(m), T = as.integer(T), 
+	ans = try(.C("armaxsim", model = as.integer(model), pars = as.double(ipars[,1]),
+					idx = as.integer(idx[,1]-1), x = as.double(x), res = as.double(res),
+					constm = as.double(constm), m = as.integer(m), T = as.integer(T),
 					PACKAGE = "rugarch"), silent = TRUE)
 	if(inherits(ans, "try-error")){
 		return(0)
@@ -158,9 +159,9 @@
 	d = max(1e-9, d)
 	d = min(0.5-1e-9, d)
 	ans = list()
-	ans = try(.Fortran("fdsim", n = T, ip = as.integer( model[2] ), iq = as.integer( model[3] ), 
-					ar = as.double( ipars[idx["ar",1]:idx["ar",2], 1] ), 
-					ma = as.double( ipars[idx["ma",1]:idx["ma",2], 1] ), 
+	ans = try(.Fortran("fdsim", n = T, ip = as.integer( model[2] ), iq = as.integer( model[3] ),
+					ar = as.double( ipars[idx["ar",1]:idx["ar",2], 1] ),
+					ma = as.double( ipars[idx["ma",1]:idx["ma",2], 1] ),
 					d = as.double(d),
 					rmu = constm, y = res, s = s, flmin = flmin, flmax = flmax,
 					epmin = epmin, epmax = epmax,
@@ -172,4 +173,4 @@
 		ans$s = NULL
 		return(ans)
 	}
-}
\ No newline at end of file
+}
